﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.Text;
using System.Security.Cryptography;
using System.IO;

namespace EAFUpload
{
    public partial class UploadToAmazon : System.Web.UI.Page
    {
        //------------ Amazon S3 account data -------------//

        // This key plays role of password . It's called secret because it is assumed to be known to owner only.
        // See also http://aws.amazon.com/account/ -> Security Credentials 
        public string AWS_SECRET_KEY = "";

        // The AWS Access Key ID of the owner of the bucket 
        // who grants an Anonymous user access for a request that satisfies the set of constraints in the Policy.
        public string AwsAccessKey = "";

        //Name of the bucket the file will be uploaded to.
        public string bucket = "";

        //Name of the bucket's folder the file will be uploaded to.
        public string folder = "";
        
        // Specifies an Amazon S3 access control list. If an invalid access control list is specified, an error is generated.
        // Should be "public-read" for POST upload.
        public string acl = "public-read";

        //The status code returned to the client upon successful upload if success_action_redirect is not specified.
        //Accepts the values 200, 201, or 204 (default).
        //If the value is set to 200 or 204, Amazon S3 returns an empty document with a 200 or 204 status code.
        //If the value is set to 201, Amazon S3 returns an XML document with a 201 status code. For information on the content of the XML document.        
        // We recommend to use "201" http status code.
        public string successActionStatus = "201";

        // The expiration specifies the expiration date of the policy in ISO8601 GMT date format. 
        // For example, "2007-12-01T12:00:00.000Z" specifies that the policy is not valid after 12:00 GMT on 2007-12-01.
        string uploadExpiration;

        //------------ Amazon S3 account data -------------//
        
        public string sigPolicyDoc = "";
        public string policyDoc64 = "";     
        
        protected void Page_Load(object sender, EventArgs e)
        {
            uploadExpiration = DateTime.Now.AddDays(1).ToString("yyyy-MM-dd") + "T00:00:00Z";
            
            policyDoc64 = Convert.ToBase64String(Encoding.UTF8.GetBytes(createPolicy()));
            sigPolicyDoc = createSignature();
        }

        string createPolicy()
        {
            StringBuilder policyBuilder = new StringBuilder(

            "{\"expiration\": \"$uploadExpiration\"," +
               "\"conditions\": [" +
                "{\"bucket\": \"$bucketName\"}," +
                "[\"starts-with\", \"$key\", \"$folder\"]," +
                "[\"starts-with\", \"$Filename\", \"\"]," +
                "{\"success_action_status\": \"$successActionStatus\"}," +
                "{\"acl\": \"$acl\"}" +
              "]" +
            "}");

            policyBuilder.Replace("$uploadExpiration", uploadExpiration);
            policyBuilder.Replace("$bucketName", bucket);
            policyBuilder.Replace("$folder", folder);
            policyBuilder.Replace("$successActionStatus", successActionStatus);
            policyBuilder.Replace("$acl", acl);
            

            return policyBuilder.ToString();
        }

        string createSignature()
        {
            HMACSHA1 hmac = new HMACSHA1(Encoding.UTF8.GetBytes(AWS_SECRET_KEY));
            CryptoStream cs = new CryptoStream(Stream.Null, hmac, CryptoStreamMode.Write);
            cs.Write(Encoding.UTF8.GetBytes(policyDoc64), 0, policyDoc64.Length);
            cs.Close();

            return Convert.ToBase64String(hmac.Hash);
        }
    }
}
