<?php

//------------ Amazon S3 account data -------------//

// This key plays role of password . It's called secret because it is assumed to be known to owner only.
// See also http://aws.amazon.com/account/ -> Security Credentials
$AWS_SECRET_KEY = '';

// The AWS Access Key ID of the owner of the bucket 
// who grants an Anonymous user access for a request that satisfies the set of constraints in the Policy.
$AwsAccessKey = '';

//Name of the bucket the file will be uploaded to.
$bucketName   = '';

//Name of the bucket's folder the file will be uploaded to.
$folder       = '';

// Specifies an Amazon S3 access control list. If an invalid access control list is specified, an error is generated.
// Should be "public-read" for POST upload.
$acl          = 'public-read';

//The status code returned to the client upon successful upload if success_action_redirect is not specified.
//Accepts the values 200, 201, or 204 (default).
//If the value is set to 200 or 204, Amazon S3 returns an empty document with a 200 or 204 status code.
//If the value is set to 201, Amazon S3 returns an XML document with a 201 status code. For information on the content of the XML document.        
// We recommend to use "201" http status code.
$successActionStatus   = '201';

// The expiration specifies the expiration date of the policy in ISO8601 GMT date format. 
// For example, "2007-12-01T12:00:00.000Z" specifies that the policy is not valid after 12:00 GMT on 2007-12-01.
$uploadExpiration = date('Y-m-d', strtotime('+1 day')) . 'T00:00:00Z';

//------------ Amazon S3 account data -------------//

$policy=<<<CONT
{"expiration": "$uploadExpiration",
  "conditions": [
    {"bucket": "$bucketName"},
    ["starts-with", "\$key", "$folder"],
    ["starts-with", "\$Filename", ""],	
    {"success_action_status": "$successActionStatus"},		
    {"acl": "$acl"}
  ]
}

CONT;

$policy = implode(explode('\n', implode(explode('\r', $policy))));

// create policy document
$policyDoc64 = base64_encode($policy); // encode to base 64

// create policy document signature
$sigPolicyDoc = base64_encode(hash_hmac("sha1", $policyDoc64, $AWS_SECRET_KEY, TRUE));

?>
<html>
  <head>
    <title>Multiple files upload to Amazon S3 service.</title>
    <link rel="stylesheet" href="style.css" />
</head>
<body>
<p>
This example demonstrates how to upload multiple files to the Amazon S3 service.
</p>
<div style="border: 1px solid #000000; padding: 10px;">
<b>Before running this examples</b> please fill all nessesary data related to your Amazon S3 account at the PHP code of this file.<br />
Also you should place <b>crossdomain.xml</b> file to root folder of your bucket.
<br /><br />
<b>Note:</b> Trial version has two limitiations: maximum files count is 10 and size of each file cannot be larger than 50 MB.
</div>
    <form name="form1">
      <input type="hidden" name="AWSAccessKeyId" value="<?php echo $AwsAccessKey ?>">
      <input type="hidden" name="signature" value="<?php echo $sigPolicyDoc ?>">
      <input type="hidden" name="policy" value="<?php echo $policyDoc64 ?>">

      <!-- UPLOAD DESC FIELDS -->
      <input type="hidden" name="acl" value="<?php echo $acl ?>">
	  <input type="hidden" name="success_action_status" value="<?php echo $successActionStatus ?>">

      <!-- CUSTOM META FIELDS -->
    </form>
<br /><br />

<div id="EAFlashUpload_holder">
You need at least Adobe Flash Player 10 for successful work. Download the latest version from here:
<br />
<a href="http://www.adobe.com/support/flashplayer/downloads.html">Adobe Flash Player</a>
</div>

<!-- Embedding the EAFlashUpload control -->
<script type="text/javascript" src="EAFUpload/swfobject.js"></script>
<script type="text/javascript">
    var params = {
        BGcolor: "#ffffff",
        wmode: "window"
    };
    var attributes = {
        id: "EAFlashUpload",
        name: "EAFlashUpload"
    };

    var flashvars = new Object();

    flashvars["uploader.uploadUrl"] = "http://<?PHP echo $bucketName?>.s3.amazonaws.com/";
    flashvars["viewFile"] = "EAFUpload/TableView.swf";
    flashvars["uploader.formToSend"] = "form1";

    // We need to get rid of unnecessary form fields
    // otherwise they should be described in the policy.
    flashvars['uploader.sendFileAttributes'] = false; 
    flashvars['uploader.queueDataInLastRequest'] = false;
    flashvars['uploader.retrieveBrowserCookie'] = false;
    
    flashvars['uploader.successHttpStatusCodes'] = "200|201";
    flashvars['queue.fileFormFieldName'] = 'file';

    // redirects user after successful upload
    flashvars["uploader.redirectUrl"] = "successredirectpage.php";
    flashvars["uploader.redirectTarget"] = "_self";
    flashvars["uploader.redirectMethod"] = "POST";

    swfobject.embedSWF("EAFUpload/EAFUpload.swf", "EAFlashUpload_holder", "450", "350", "10.0.0", "EAFUpload/expressInstall.swf", flashvars, params, attributes);

    function EAFlashUpload_onUploadStart() {

        var files = EAFlashUpload.getFiles();
        var propertyObject = new Object();

        // Below we define a new form field for each file.
        // You can use this code to specify a name of the file which will be used for stroing file on the Amazon S3.
        for (var index in files) {
            propertyObject.name = "key";
            propertyObject.value = "<?PHP echo $folder?>" + files[index].name;
            propertyObject.isPublic = false;
            propertyObject.fileId = files[index].id;
            propertyObject.strongName = true;

            EAFlashUpload.setCustomProperty(propertyObject);
        }
    }

    function EAFlashUpload_onFileLoadEnd(fileObj) 
    {
        var propertyObject = new Object();
        propertyObject.name = "downloadLink";

        if(fileObj.serverResponse != "")
        {
            var downloadLink = "";
            // retrieve a file location on the Amazon S3 server.
            downloadLink = fileObj.serverResponse.match(/<Location>(.*?)<\/Location>/g);
            downloadLink = downloadLink[0].replace(/<Location>|<\/Location>/g, "");
			
            propertyObject.value = downloadLink;
        }
        else
            propertyObject.value = "";
        
        propertyObject.isPublic = false;
        propertyObject.fileId = fileObj.id;
        propertyObject.strongName = true;

        EAFlashUpload.setCustomProperty(propertyObject);
    }
</script>

<br />
<hr />
<div style="padding: 10px; font-weight: bold;">
Note: If you have questions regarding this example please let us know <a href="mailto:support%40easyalgo.com?Subject=UploadToAmazonPHP">support@easyalgo.com</a>. Any assistance is provided for free.
</div>
<a href="index.php">Other examples</a>				

</body>
</html>